*Notes for readers:  The variable "tpc" is terrorism per capita based on the 
*number of observations in the Global Terrorism Database in a given country in a
*given year and divided by the population in that country in that year, as 
*according to the World Bank Open Data database.  
*The variable "lagtpc" is the lag of "tpc", while "midtpc" is the average of tpc
*and lagtpc, following the trapezoidal method. "lagtpc2" represents lagtpc 
*squared and midtpc2 represents the average of squares, evaluated in the way 
*described in the appendix of the paper.

*The variable "terrorclustclassification" is a categorical variable, output from
*R using the MCLUST utility.

*The GTD data can be downloaded from the GTD page http://www.start.umd.edu/gtd/

*The variables tested as controls can be obtained from the world bank's
*Stata utility
*type "ssc install wbopendata"
*type "db wbopendata"

*generare illustration 1 and 2 in R using MCLUST
*generate illustration 3
twoway (scatter d.tpc midtpc) (lfitci d.tpc midtpc) if L.terrorclustclassification < 4
*generate illustration 4
xtdpdsys d.tpc dum , endogenous(midtpc midtpc2) vce(gmm) maxlags(2) 
estimates store roger
*levels
forvalues i=1/75 {
estimates restore roger
nlcom _b[midtpc]*`i'*.00001+_b[midtpc2]*(`i'*.00001)^2+_b[_cons] , post
replace up = _b[_nl_1] + 2* _se[_nl_1] in `i'
replace down = _b[_nl_1] - 2* _se[_nl_1] in `i'
replace est = _b[_nl_1] in `i'
replace scale = `i'*.00001 in `i'
}
line est scale || line up scale ||line down scale



*Reproduce tables from the paper
*Note: Arellano-Bond tests are added manually to tables
xtdpdsys d.tpc if L.terrorclustclassification <2, pre(lagtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table1.out", word replace

xtdpdsys d.tpc if L.terrorclustclassification <3, pre(lagtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table1.out", word append

xtdpdsys d.tpc if L.terrorclustclassification <4, pre(lagtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table1.out", word append

xtdpdsys d.tpc if L.terrorclustclassification <5, pre(lagtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table1.out", word append

xtdpdsys d.tpc if L.terrorclustclassification <6, pre(lagtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table1.out", word append



*table 2
xtdpdsys d.tpc if L.terrorclustclassification <2, endogenous(midtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table2.out", word replace

xtdpdsys d.tpc if L.terrorclustclassification <3, endogenous(midtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table2.out", word append

xtdpdsys d.tpc if L.terrorclustclassification <4, endogenous(midtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table2.out", word append

xtdpdsys d.tpc if L.terrorclustclassification <5, endogenous(midtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table2.out", word append

xtdpdsys d.tpc if L.terrorclustclassification <6, endogenous(midtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table2.out", word append


*table 3
xtdpdsys d.tpc dum if L.terrorclustclassification <3, pre(lagtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table3.out", word replace

xtdpdsys d.tpc dum if L.terrorclustclassification <4, pre(lagtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table3.out", word append

xtdpdsys d.tpc dum if L.terrorclustclassification <5, pre(lagtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table3.out", word append

xtdpdsys d.tpc dum if L.terrorclustclassification <6, pre(lagtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table3.out", word append



*table 4
xtdpdsys d.tpc dum if L.terrorclustclassification <3, endogenous(midtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table4.out", word replace

xtdpdsys d.tpc dum if L.terrorclustclassification <4, endogenous(midtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table4.out", word append

xtdpdsys d.tpc dum if L.terrorclustclassification <5, endogenous(midtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table4.out", word append

xtdpdsys d.tpc dum if L.terrorclustclassification <6, endogenous(midtpc) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table4.out", word append


*table 5
xtivreg2 d.tpc L.tpc dum (L.tpc =L2.tpc ) if L.terrorclustclassification <3, rob fe cue
outreg2 using "E:\work\terror\table5.out", word replace
xtivreg2 d.tpc L.tpc dum (L.tpc =L2.tpc ) if L.terrorclustclassification <4, rob fe cue
outreg2 using "E:\work\terror\table5.out", word app
xtivreg2 d.tpc L.tpc dum (L.tpc =L2.tpc ) if L.terrorclustclassification <5, rob fe cue
outreg2 using "E:\work\terror\table5.out", word app
xtivreg2 d.tpc L.tpc dum (L.tpc =L2.tpc ) if L.terrorclustclassification <6, rob fe cue
outreg2 using "E:\work\terror\table5.out", word app

*table 6
xtivreg2 d.tpc midtpc dum (midtpc =L2.tpc ) if L.terrorclustclassification <3, rob fe cue
outreg2 using "E:\work\terror\table6.out", word replace
xtivreg2 d.tpc midtpc dum (midtpc =L2.tpc ) if L.terrorclustclassification <4, rob fe cue
outreg2 using "E:\work\terror\table6.out", word app
xtivreg2 d.tpc midtpc dum (midtpc =L2.tpc ) if L.terrorclustclassification <5, rob fe cue
outreg2 using "E:\work\terror\table6.out", word app
xtivreg2 d.tpc midtpc dum (midtpc =L2.tpc ) if L.terrorclustclassification <6, rob fe cue
outreg2 using "E:\work\terror\table6.out", word app


*table 7
xi: xtdpdsys d.tpc  , pre(lagtpc lagtpc2) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table7.out", word replace

xi: xtdpdsys d.tpc dum , pre(lagtpc lagtpc2) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table7.out", word append

xtdpdsys d.tpc  , endogenous(midtpc midtpc2) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table7.out", word append

xtdpdsys d.tpc dum , endogenous(midtpc midtpc2) vce(rob) maxlags(2) 
estat abond
outreg2 using "E:\work\terror\table7.out", word append

*table 8
xi: xtdpdsys d.tpc  i.region , pre(lagtpc lagtpc2) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table8.out", word replace

xi: xtdpdsys d.tpc dum i.region , pre(lagtpc lagtpc2) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table8.out", word append

xi: xtdpdsys d.tpc  i.region , endogenous(midtpc midtpc2) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table8.out", word append

xi: xtdpdsys d.tpc dum i.region , endogenous(midtpc midtpc2) vce(rob) maxlags(2)
estat abond
outreg2 using "E:\work\terror\table8.out", word append

*table 9
xtivreg2 d.tpc L.tpc L.tpc2 L.tpc3 (L.tpc L.tpc2 L.tpc3=L2.tpc L2.tpc2), rob fe cue
outreg2 using "E:\work\terror\table9.out", word replace
xtivreg2 d.tpc L.tpc L.tpc2 L.tpc3 dum (L.tpc L.tpc2 L.tpc3=L2.tpc L2.tpc2), rob fe cue
outreg2 using "E:\work\terror\table9.out", word append
xtivreg2 d.tpc midtpc midtpc2 (midtpc midtpc2=L2.tpc L2.tpc2), rob fe cue
outreg2 using "E:\work\terror\table9.out", word append
xtivreg2 d.tpc midtpc midtpc2 dum (midtpc midtpc2=L2.tpc L2.tpc2), rob fe cue
outreg2 using "E:\work\terror\table9.out", word append

*table 10
xi: xtdpdsys tpc  , pre(lagtpc lagtpc2) vce(rob) maxlags(2) two
estat abond
outreg2 using "E:\work\terror\table10.out", word replace
xi: xtdpdsys tpc dum  , pre(lagtpc lagtpc2) vce(rob) maxlags(2) two
estat abond
outreg2 using "E:\work\terror\table10.out", word append
xi: xtdpdsys tpc  i.region , pre(lagtpc lagtpc2) vce(rob) maxlags(2) two
estat abond
outreg2 using "E:\work\terror\table10.out", word append
xi: xtdpdsys tpc dum i.region , pre(lagtpc lagtpc2) vce(rob) maxlags(2) two
estat abond
outreg2 using "E:\work\terror\table10.out", word append

*table 11
xtivreg2 tpc L.tpc L.tpc2 L.tpc3 (L.tpc L.tpc2=L2.tpc L2.tpc2), rob fd cue
outreg2 using "E:\work\terror\table11.out", word replace

xtivreg2 tpc L.tpc L.tpc2 L.tpc3 dum (L.tpc L.tpc2 L.tpc3=L2.tpc L2.tpc2), rob fd cue
outreg2 using "E:\work\terror\table11.out", word append

xtivreg2 tpc L.tpc L.tpc2 L.tpc3 (L.tpc L.tpc2 L.tpc3=L2.tpc L2.tpc2), rob fe cue
outreg2 using "E:\work\terror\table11.out", word append

xtivreg2 tpc L.tpc L.tpc2 L.tpc3 dum (L.tpc L.tpc2 L.tpc3=L2.tpc L2.tpc2), rob fe cue
outreg2 using "E:\work\terror\table11.out", word append


